Package: ggdendro
Authors@R: c(person("Andrie", "de Vries", role=c("aut", "cre"),
    email="apdevries@gmail.com"), person(c("Brian", "D."), "Ripley", role =
    c("aut"), comment = "author of package tree"))
License: GPL-2 | GPL-3
Title: Create Dendrograms and Tree Diagrams Using 'ggplot2'
LazyData: true
LazyLoad: true
ByteCompile: true
Description: This is a set of tools for dendrograms and
    tree plots using 'ggplot2'.  The 'ggplot2' philosophy is to
    clearly separate data from the presentation.
    Unfortunately the plot method for dendrograms plots
    directly to a plot device without exposing the data.
    The 'ggdendro' package resolves this by making available
    functions that extract the dendrogram plot data. The package
    provides implementations for tree, rpart, as well as diana and agnes
    cluster diagrams.
Version: 0.1-20
URL: https://github.com/andrie/ggdendro
BugReports: https://github.com/andrie/ggdendro/issues
Date: 2016-04-27
Imports: MASS, ggplot2(>= 0.9.2)
Suggests: rpart(>= 4.0-0), tree, testthat, knitr, cluster, scales
VignetteBuilder: knitr
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2016-04-27 10:47:14 UTC; adevries
Author: Andrie de Vries [aut, cre],
  Brian D. Ripley [aut] (author of package tree)
Maintainer: Andrie de Vries <apdevries@gmail.com>
Repository: CRAN
Date/Publication: 2016-04-27 18:28:33
Built: R 3.3.2; ; 2017-11-13 08:16:55 UTC; windows
